/* Agresti, A.  1990.  Categorical Data Analysis.
 * John Wiley & Sons: New York.  558pp.
 * Example pp. 87 - 89.
 */
#include <dap.h>

void main()
{
  infile("cda88.dat", " ")
    {
      double labind, ncases, nremiss;
      input("labind ncases nremiss");
      outset("cda88", "");
      skip(1);
      while (step())
        output();
    }

  nport(plotlogreg("cda88", "nremiss/ncases", "labind", "==", 5, "", 1, 0.95), 4, 4);
}
